﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace ArgowMobile_ui {
  public partial class frmArgowMobile_ui : Form {
    public frmArgowMobile_ui() {
      InitializeComponent();
      txbAbout.Text = txbAbout.Text.Replace("\r\n", "").Replace("|", "\r\n");
      txbAbout.WordWrap = true;
      txbAbout.Left = pnlArgow.ClientRectangle.Right - txbAbout.Width;
    }
    private string IncludeTrailingPathDelimiter(string cPath) {
      return cPath + (cPath.EndsWith(System.IO.Path.DirectorySeparatorChar.ToString()) ? "" : System.IO.Path.DirectorySeparatorChar.ToString());
    }
    private void enableButtons(Boolean value) {
      btnGet.Enabled = value;
      btnPut.Enabled = value;
      btnOpen.Enabled = value;
      btnInfo.Enabled = value;
      Cursor.Current = (value) ? Cursors.Default : Cursors.WaitCursor;
    }
    private void btnPut_Click(object sender, EventArgs e) {
      string cSource = IncludeTrailingPathDelimiter(txbFolder_PC.Text) + txbFileName.Text;
      string cDestiny = IncludeTrailingPathDelimiter(txbFolder_Mobile.Text) + txbFileName.Text;
      enableButtons(false);
      try {
        int i = argow.utils.mobile.copyPcToMobile(cSource, cDestiny);
        if (i == 0) {
          MessageBox.Show("Arquivo " + cSource + " copiado no Mobile.", btnPut.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
        } else {
          MessageBox.Show("Não foi possível copiar o arquivo " + cSource + " ao Mobile, erro " + i.ToString(), btnPut.Text, MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
      } finally {
        enableButtons(true);
      }

    }
    private void btnGet_Click(object sender, EventArgs e) {
      string cSource = IncludeTrailingPathDelimiter( txbFolder_Mobile.Text ) + txbFileName.Text;
      string cDestiny = IncludeTrailingPathDelimiter( txbFolder_PC.Text ) + txbFileName.Text;
      enableButtons(false);
      try {
        int i = argow.utils.mobile.copyMobileToPc(cSource, cDestiny);
        if (i == 0) {
          MessageBox.Show("Arquivo " + cSource + " copiado ao PC.", btnPut.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
        } else {
          MessageBox.Show("Não foi possível copiar o arquivo " + cSource + " ao PC, erro " + i.ToString(), btnPut.Text, MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
      } finally {
        enableButtons(true);
      }
    }
    private void btnOpen_Click(object sender, EventArgs e) {
      if (openFileDialog.ShowDialog() == DialogResult.OK) {
        txbFileName.Text = System.IO.Path.GetFileName(openFileDialog.FileName);
        txbFolder_PC.Text = System.IO.Path.GetDirectoryName(openFileDialog.FileName);
      }
    }
    private void btnInfo_Click(object sender, EventArgs e) {
      enableButtons(false);
      try {
        txbInfo.Text = System.DateTime.Now.ToShortDateString() + " " + System.DateTime.Now.ToLongTimeString() + "\r\n";
        Dictionary<string, string> oDic = new Dictionary<string, string>();
        if (argow.utils.mobile.getInfo(ref oDic)) {
          foreach( KeyValuePair<string, string> item in oDic){
            txbInfo.Text+= item.Key + "= " + item.Value + "\r\n";
          }
        } else {
          txbInfo.Text+= "Dispositivo não encontrado.";
        }
      } finally {
        enableButtons(true);
      }
    }

    private void lblArgow_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e) {
      System.Diagnostics.Process.Start( lblArgow.Text );
    }

  }
}
