unit arMobile_interface;

interface
  uses
   arMobile_const;

	type
		TArMobileInfo= record
			code: integer;
			batteryLeft: word;
			usedMemory: word;
			charging: Boolean;
			osVerMajor: word;
			osVerMinor: word;
		end;

	function mobile_getInfo( const iTimeOut: word; var info: TArMobileInfo ): boolean;
  function mobile_copyMobileToPC( const cSource, cDestiny: pChar ): integer;
  function mobile_copyPCToMobile( const cSource, cDestiny: pChar ): integer;
  function mobile_fileExists( const cSource ): boolean;
  function mobile_init(): boolean;
  procedure mobile_finalize();

implementation
	uses
    {$ifdef MOBILE_TEST}
      arMobile_base,
    {$EndIf}
    Classes,
		SysUtils,
		Windows;

  type
    TMobile_getInfo = function( const nTimeOut, nSize: word; lpInfo: PWideChar ): word; stdcall;
    TMobile_transfer = function( const lpSource, lpDestiny: PWideChar; const bPcToMobile: word ): integer; stdcall;
    TMobiel_fileExists= function( const lpFileName: PWideChar ): word; stdcall;


  var
    mobile_inited: boolean= false;
    mobile_Handle: THandle= 0;
    pMobile_getInfo: TMobile_getInfo= nil;
    pMobile_transfer: TMobile_transfer= nil;
    pMobile_fileExists: TMobiel_fileExists= nil;

//------------------------------------------------------------------------------
procedure mobile_finalize();
begin
  if mobile_inited and ( mobile_Handle >= 32 ) then begin
     FreeLibrary( mobile_Handle );
     mobile_inited:= false;
  end;

end;
//------------------------------------------------------------------------------
function mobile_init(): boolean;
  {$ifndef MOBILE_TEST} var iMode: UINT; {$Endif}
begin

  result:= true;
  if mobile_inited then exit;

  {$ifdef MOBILE_TEST}
     @pMobile_getInfo:= @arMobile_base.mobile_getInfo;
     @pMobile_transfer:= @arMobile_base.mobile_transfer;
     @pMobile_fileExists:= @arMobile_base.mobile_fileExists;
     mobile_inited:= True;
  {$Else}
    iMode:= setErrorMode( SEM_FAILCRITICALERRORS );
    mobile_Handle:= LoadLibrary( ArMobile_Dll );
    result:= ( mobile_Handle >= 32 );
    if result then begin
      mobile_inited:= True;
      @pMobile_getInfo:= GetProcAddress(mobile_Handle, 'mobile_getInfo');
      @pMobile_transfer:= GetProcAddress(mobile_Handle, 'mobile_transfer');
      @pMobile_fileExists:= GetProcAddress(mobile_Handle, 'mobile_fileExists');
    end;
    setErrorMode( iMode );
  {$Endif}

end;

//------------------------------------------------------------------------------
function mobile_getInfo( const iTimeOut: word;  var info: TArMobileInfo ): boolean;
  const _s: word= 1024;
  var
    lst: TStringList;
    cBuffer: string;
    iSize: Word;
  //. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .
  function _get( const cName: string ): word;
    var i: integer;
  begin
    result:= 0;
    i:= lst.IndexOfName( cName );
    if ( i >= 0 ) then result:= StrToIntDef( lst.ValueFromIndex[i], 0 );
  end;
begin
    result:= false;
    info.code:= ArMobile_DllError;
    if not mobile_init() then exit;

    cBuffer:= StringOfChar( #0, _s );
  	iSize:= pMobile_getInfo( iTimeOut, _s, pChar( cBuffer ) );
    if ( iSize = 0 ) then begin
      info.code:= GetLastError();
    end else begin
      info.Code:= 0;
      lst:= TStringList.Create;
      try
        lst.Text:= Copy( cBuffer, 1, iSize );
        info.osVerMajor:= _get( ArMobile_OsVerMajor );
        info.osVerMinor:= _get( ArMobile_OsVerMinor );
        info.batteryLeft:= _get( ArMobile_batteryLeft );
        info.usedMemory:= _get( ArMobile_usedMem );
        info.charging:= not ( _get( ArMobile_charging ) = 0 );
      finally
        lst.Free;
      end;
    end;
    result:= ( info.code = 0 );

end;

//------------------------------------------------------------------------------
function mobile_transfer( const cSource, cDestiny: string; const bPcToMobile: boolean ): integer;
begin

  if not mobile_init() then begin
    result:= ERROR_DLL_INIT_FAILED;
  end else if ( cSource = '' ) or ( cDestiny = '' ) then begin
		result:= ERROR_FILE_NOT_FOUND
	end else if bPcToMobile and not fileExists( cSource ) then begin
		result:= ERROR_FILE_NOT_FOUND;
	end else begin
  	result:= pMobile_transfer( pChar(cSource), pChar(cDestiny), word(bPcToMobile) );
  end;

end;

//------------------------------------------------------------------------------
function mobile_fileExists( const cSource ): boolean;
begin
  result:= false;
  if mobile_init() then begin
    SetLastError( ERROR_DLL_INIT_FAILED );
  end else begin
    result:= wordBool( pMobile_fileExists( pChar( cSource ) ));
  end;

end;

//------------------------------------------------------------------------------
function mobile_copyMobileToPC( const cSource, cDestiny: pChar ): integer;
begin
  result:= mobile_transfer( cSource, cDestiny, false );

end;

//------------------------------------------------------------------------------
function mobile_copyPCToMobile( const cSource, cDestiny: pChar ): integer;
begin
  result:= mobile_transfer( cSource, cDestiny, true );

end;

//------------------------------------------------------------------------------
initialization;

finalization;
  mobile_finalize;

end.
